#
# spec file for package ghc-hslua-module-doclayout
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name hslua-module-doclayout
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.2.0
Release:        1.10
Summary:        Lua module wrapping Text.DocLayout
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-doclayout-devel
BuildRequires:  ghc-doclayout-prof
BuildRequires:  ghc-hslua-devel
BuildRequires:  ghc-hslua-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-lua-devel
BuildRequires:  ghc-tasty-lua-prof
BuildRequires:  ghc-tasty-prof
%endif

%description
Lua module wrapping 'Text.DocLayout'.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library
development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sat Sep 21 2024 Peter Simons <psimons@suse.com>
- Update hslua-module-doclayout to version 1.2.0.
  [#]# 1.2.0
  Released 2024-09-21.
  - Require doclayout-0.5.
  - Add new styling functions `bold`, `italic`, `underlined`,
    `strikeout`, `fg`, and `bg`.
  - The `render` function now takes `style` as a third parameter.
    It must be either 'plain' or 'ansi' when given.
* Mon Sep  9 2024 Peter Simons <psimons@suse.com>
- Update hslua-module-doclayout to version 1.1.1.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Jun 10 2024 Peter Simons <psimons@suse.com>
- Update hslua-module-doclayout to version 1.1.1.2.
  [#]# 1.1.1.2
  Released 2024-06-10.
  - Fixed another documentation bugs: `render` returns a `string`.
  [#]# 1.1.1.1
  Released 2024-06-09.
  - Fixed minor typos in docstrings.
* Tue Jan 23 2024 Peter Simons <psimons@suse.com>
- Update hslua-module-doclayout to version 1.1.1.
  [#]# 1.1.1
  Released 2024-01-23.
  - Relaxed upper bound for text, allowing text-2.1.
  - Improved doc strings.
  - Test with latest GHC versions.
* Thu Apr 13 2023 Peter Simons <psimons@suse.com>
- Update hslua-module-doclayout to version 1.1.0.
  [#]# 1.1.0
  Release pending.
  - Require hslua-2.3 and tasty-lua-1.1.
  - Type info is added to all fields.
  - The `Doc` type is now associated with this module's docs,
    making it easier to generate documentation.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Apr  3 2022 Peter Simons <psimons@suse.com>
- Add hslua-module-doclayout at version 1.0.4.
